@@ -1,20 +1,21 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public License
+ *  as published by the Free Software Foundation; either version 2.1
+ *  of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free
+ *  Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
+ *  02110-1301, USA.
  */
 
 
@@ -30,6 +31,17 @@
 
 #define d(x)
 
+
+/**
+ * SECTION: gmime-filter-html
+ * @title: GMimeFilterHTML
+ * @short_description: Convert plain text into HTML
+ * @see_also: #GMimeFilter
+ *
+ * A #GMimeFilter used for converting plain text into HTML.
+ **/
+
+
 #define CONVERT_WEB_URLS  GMIME_FILTER_HTML_CONVERT_URLS
 #define CONVERT_ADDRSPEC  GMIME_FILTER_HTML_CONVERT_ADDRESSES
 
@@ -37,16 +49,16 @@ static struct {
 	unsigned int mask;
 	urlpattern_t pattern;
 } patterns[] = {
-	{ CONVERT_WEB_URLS, { "file://",   "",        g_url_file_start,     g_url_file_end     } },
-	{ CONVERT_WEB_URLS, { "ftp://",    "",        g_url_web_start,      g_url_web_end      } },
-	{ CONVERT_WEB_URLS, { "http://",   "",        g_url_web_start,      g_url_web_end      } },
-	{ CONVERT_WEB_URLS, { "https://",  "",        g_url_web_start,      g_url_web_end      } },
-	{ CONVERT_WEB_URLS, { "news://",   "",        g_url_web_start,      g_url_web_end      } },
-	{ CONVERT_WEB_URLS, { "nntp://",   "",        g_url_web_start,      g_url_web_end      } },
-	{ CONVERT_WEB_URLS, { "telnet://", "",        g_url_web_start,      g_url_web_end      } },
-	{ CONVERT_WEB_URLS, { "www.",      "http://", g_url_web_start,      g_url_web_end      } },
-	{ CONVERT_WEB_URLS, { "ftp.",      "ftp://",  g_url_web_start,      g_url_web_end      } },
-	{ CONVERT_ADDRSPEC, { "@",         "mailto:", g_url_addrspec_start, g_url_addrspec_end } },
+	{ CONVERT_WEB_URLS, { "file://",   "",        url_file_start,     url_file_end     } },
+	{ CONVERT_WEB_URLS, { "ftp://",    "",        url_web_start,      url_web_end      } },
+	{ CONVERT_WEB_URLS, { "http://",   "",        url_web_start,      url_web_end      } },
+	{ CONVERT_WEB_URLS, { "https://",  "",        url_web_start,      url_web_end      } },
+	{ CONVERT_WEB_URLS, { "news://",   "",        url_web_start,      url_web_end      } },
+	{ CONVERT_WEB_URLS, { "nntp://",   "",        url_web_start,      url_web_end      } },
+	{ CONVERT_WEB_URLS, { "telnet://", "",        url_web_start,      url_web_end      } },
+	{ CONVERT_WEB_URLS, { "www.",      "http://", url_web_start,      url_web_end      } },
+	{ CONVERT_WEB_URLS, { "ftp.",      "ftp://",  url_web_start,      url_web_end      } },
+	{ CONVERT_ADDRSPEC, { "@",         "mailto:", url_addrspec_start, url_addrspec_end } },
 };
 
 #define NUM_URL_PATTERNS (sizeof (patterns) / sizeof (patterns[0]))
@@ -110,7 +122,7 @@ g_mime_filter_html_class_init (GMimeFilterHTMLClass *klass)
 static void
 g_mime_filter_html_init (GMimeFilterHTML *filter, GMimeFilterHTMLClass *klass)
 {
-	filter->scanner = g_url_scanner_new ();
+	filter->scanner = url_scanner_new ();
 	
 	filter->flags = 0;
 	filter->colour = 0;
@@ -123,7 +135,7 @@ g_mime_filter_html_finalize (GObject *object)
 {
 	GMimeFilterHTML *html = (GMimeFilterHTML *) object;
 	
-	g_url_scanner_free (html->scanner);
+	url_scanner_free (html->scanner);
 	
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -354,7 +366,7 @@ html_convert (GMimeFilter *filter, char *in, size_t inlen, size_t prespace,
 			len = inptr - start;
 			
 			do {
-				if (g_url_scanner_scan (html->scanner, start, len, &match)) {
+				if (url_scanner_scan (html->scanner, start, len, &match)) {
 					/* write out anything before the first regex match */
 					outptr = writeln (filter, start, start + match.um_so,
 							  outptr, &outend);
@@ -476,7 +488,7 @@ g_mime_filter_html_new (guint32 flags, guint32 colour)
 	
 	for (i = 0; i < NUM_URL_PATTERNS; i++) {
 		if (patterns[i].mask & flags)
-			g_url_scanner_add (new->scanner, &patterns[i].pattern);
+			url_scanner_add (new->scanner, &patterns[i].pattern);
 	}
 	
 	return (GMimeFilter *) new;
