@@ -27,7 +27,7 @@
 
 #include "gmime-message-part.h"
 
-#define d(x) x
+#define d(x)
 
 
 /**
@@ -303,7 +303,8 @@ g_mime_message_part_get_message (GMimeMessagePart *part)
 {
 	g_return_val_if_fail (GMIME_IS_MESSAGE_PART (part), NULL);
 	
-	g_object_ref (part->message);
+	if (part->message)
+		g_object_ref (part->message);
 	
 	return part->message;
 }
