@@ -58,7 +58,7 @@ static void message_remove_header (GMimeObject *object, const char *header);
 static char *message_get_headers (GMimeObject *object);
 static ssize_t message_write_to_stream (GMimeObject *object, GMimeStream *stream);
 
-static void message_add_recipients_from_string (GMimeMessage *message, char *type, const char *string);
+static void message_add_recipients_from_string (GMimeMessage *message, const char *type, const char *string);
 
 static ssize_t write_structured (GMimeStream *stream, const char *name, const char *value);
 static ssize_t write_addrspec (GMimeStream *stream, const char *name, const char *value);
@@ -1014,7 +1014,7 @@ sync_recipient_header (GMimeMessage *message, const char *type)
  * #GMIME_RECIPIENT_TYPE_CC and #GMIME_RECIPIENT_TYPE_BCC.
  **/
 void
-g_mime_message_add_recipient (GMimeMessage *message, char *type, const char *name, const char *address)
+g_mime_message_add_recipient (GMimeMessage *message, const char *type, const char *name, const char *address)
 {
 	InternetAddressList *recipients;
 	InternetAddress *ia;
@@ -1032,13 +1032,13 @@ g_mime_message_add_recipient (GMimeMessage *message, char *type, const char *nam
 	recipients = internet_address_list_append (recipients, ia);
 	internet_address_unref (ia);
 	
-	g_hash_table_insert (message->recipients, type, recipients);
+	g_hash_table_insert (message->recipients, (char *) type, recipients);
 	sync_recipient_header (message, type);
 }
 
 
 static void
-message_add_recipients_from_string (GMimeMessage *message, char *type, const char *string)
+message_add_recipients_from_string (GMimeMessage *message, const char *type, const char *string)
 {
 	InternetAddressList *recipients, *addrlist;
 	
@@ -1050,7 +1050,7 @@ message_add_recipients_from_string (GMimeMessage *message, char *type, const cha
 		internet_address_list_destroy (addrlist);
 	}
 	
-	g_hash_table_insert (message->recipients, type, recipients);
+	g_hash_table_insert (message->recipients, (char *) type, recipients);
 }
 
 
@@ -1067,7 +1067,7 @@ message_add_recipients_from_string (GMimeMessage *message, char *type, const cha
  * specified in rfc822.
  **/
 void
-g_mime_message_add_recipients_from_string (GMimeMessage *message, char *type, const char *string)
+g_mime_message_add_recipients_from_string (GMimeMessage *message, const char *type, const char *string)
 {
 	g_return_if_fail (GMIME_IS_MESSAGE (message));
 	g_return_if_fail (type != NULL);
