@@ -101,8 +101,8 @@ const char *g_mime_message_get_sender (GMimeMessage *message);
 void g_mime_message_set_reply_to (GMimeMessage *message, const char *reply_to);
 const char *g_mime_message_get_reply_to (GMimeMessage *message);
 
-void g_mime_message_add_recipient (GMimeMessage *message, char *type, const char *name, const char *address);
-void g_mime_message_add_recipients_from_string (GMimeMessage *message, char *type, const char *string);
+void g_mime_message_add_recipient (GMimeMessage *message, const char *type, const char *name, const char *address);
+void g_mime_message_add_recipients_from_string (GMimeMessage *message, const char *type, const char *string);
 const InternetAddressList *g_mime_message_get_recipients (GMimeMessage *message, const char *type);
 InternetAddressList *g_mime_message_get_all_recipients (GMimeMessage *message);
 
