@@ -237,11 +237,10 @@ g_mime_multipart_encrypted_encrypt (GMimeMultipartEncrypted *mpe, GMimeObject *c
 				    GMimeCipherContext *ctx, GPtrArray *recipients,
 				    GError **err)
 {
+	GMimeStream *filtered_stream, *ciphertext, *stream;
 	GMimePart *version_part, *encrypted_part;
 	GMimeContentType *content_type;
 	GMimeDataWrapper *wrapper;
-	GMimeStream *filtered_stream;
-	GMimeStream *stream, *ciphertext;
 	GMimeFilter *crlf_filter;
 	
 	g_return_val_if_fail (GMIME_IS_MULTIPART_ENCRYPTED (mpe), -1);
@@ -278,10 +277,14 @@ g_mime_multipart_encrypted_encrypt (GMimeMultipartEncrypted *mpe, GMimeObject *c
 	
 	/* construct the version part */
 	version_part = g_mime_part_new ();
-	g_mime_part_set_encoding (version_part, GMIME_PART_ENCODING_7BIT);
-	g_mime_part_set_content (version_part, "Version: 1\n", strlen ("Version: 1\n"));
 	content_type = g_mime_content_type_new_from_string (ctx->encrypt_protocol);
 	g_mime_object_set_content_type (GMIME_OBJECT (version_part), content_type);
+	g_mime_part_set_encoding (version_part, GMIME_PART_ENCODING_7BIT);
+	stream = g_mime_stream_mem_new_with_buffer ("Version: 1\n", strlen ("Version: 1\n"));
+	wrapper = g_mime_data_wrapper_new_with_stream (stream, GMIME_PART_ENCODING_7BIT);
+	g_mime_part_set_content_object (version_part, wrapper);
+	g_object_unref (wrapper);
+	g_object_unref (stream);
 	
 	mpe->protocol = g_strdup (ctx->encrypt_protocol);
 	mpe->decrypted = content;
@@ -289,19 +292,18 @@ g_mime_multipart_encrypted_encrypt (GMimeMultipartEncrypted *mpe, GMimeObject *c
 	
 	/* construct the encrypted mime part */
 	encrypted_part = g_mime_part_new_with_type ("application", "octet-stream");
-	wrapper = g_mime_data_wrapper_new ();
-	g_mime_data_wrapper_set_stream (wrapper, ciphertext);
-	g_object_unref (ciphertext);
-	g_mime_part_set_content_object (encrypted_part, wrapper);
 	g_mime_part_set_encoding (encrypted_part, GMIME_PART_ENCODING_7BIT);
+	wrapper = g_mime_data_wrapper_new_with_stream (ciphertext, GMIME_PART_ENCODING_7BIT);
+	g_mime_part_set_content_object (encrypted_part, wrapper);
+	g_object_unref (ciphertext);
 	g_object_unref (wrapper);
 	
 	/* save the version and encrypted parts */
 	/* FIXME: make sure there aren't any other parts?? */
 	g_mime_multipart_add_part (GMIME_MULTIPART (mpe), GMIME_OBJECT (version_part));
-	g_object_unref (version_part);
 	g_mime_multipart_add_part (GMIME_MULTIPART (mpe), GMIME_OBJECT (encrypted_part));
 	g_object_unref (encrypted_part);
+	g_object_unref (version_part);
 	
 	/* set the content-type params for this multipart/encrypted part */
 	g_mime_object_set_content_type_parameter (GMIME_OBJECT (mpe), "protocol", mpe->protocol);
