@@ -1,20 +1,21 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public License
+ *  as published by the Free Software Foundation; either version 2.1
+ *  of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free
+ *  Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
+ *  02110-1301, USA.
  */
 
 
@@ -37,6 +38,19 @@
 
 #define d(x)
 
+
+/**
+ * SECTION: gmime-multipart-signed
+ * @title: GMimeMultpartSigned
+ * @short_description: Signed MIME multiparts
+ * @see_also: #GMimeMultipart
+ *
+ * A #GMimeMultipartSigned part is a special subclass of
+ * #GMimeMultipart to make it easier to manipulate the
+ * multipart/signed MIME type.
+ **/
+
+
 /* GObject class methods */
 static void g_mime_multipart_signed_class_init (GMimeMultipartSignedClass *klass);
 static void g_mime_multipart_signed_init (GMimeMultipartSigned *mps, GMimeMultipartSignedClass *klass);
@@ -189,7 +203,7 @@ multipart_signed_write_to_stream (GMimeObject *object, GMimeStream *stream)
  * Returns an empty MIME multipart/signed object.
  **/
 GMimeMultipartSigned *
-g_mime_multipart_signed_new ()
+g_mime_multipart_signed_new (void)
 {
 	GMimeMultipartSigned *multipart;
 	GMimeContentType *type;
