@@ -1,20 +1,21 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public License
+ *  as published by the Free Software Foundation; either version 2.1
+ *  of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free
+ *  Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
+ *  02110-1301, USA.
  */
 
 
@@ -30,6 +31,18 @@
 #include "gmime-stream-mem.h"
 #include "gmime-utils.h"
 
+
+/**
+ * SECTION: gmime-object
+ * @title: GMimeObject
+ * @short_description: Abstract MIME objects
+ * @see_also:
+ *
+ * #GMimeObject is an abstract class from which all Message and MIME
+ * parts are derived.
+ **/
+
+
 struct _type_bucket {
 	char *type;
 	GType object_type;
@@ -78,7 +91,7 @@ g_mime_object_get_type (void)
 			NULL, /* class_finalize */
 			NULL, /* class_data */
 			sizeof (GMimeObject),
-			16,   /* n_preallocs */
+			0,    /* n_preallocs */
 			(GInstanceInitFunc) g_mime_object_init,
 		};
 		
@@ -292,7 +305,7 @@ g_mime_object_new_type (const char *type, const char *subtype)
 			return NULL;
 	}
 	
-	object = g_object_new (obj_type, NULL, NULL);
+	object = g_object_new (obj_type, NULL);
 	
 	GMIME_OBJECT_GET_CLASS (object)->init (object);
 	
@@ -679,8 +692,8 @@ g_mime_object_to_string (GMimeObject *object)
 	g_mime_object_write_to_stream (object, stream);
 	
 	g_object_unref (stream);
-	g_byte_array_append (array, "", 1);
-	str = array->data;
+	g_byte_array_append (array, (unsigned char *) "", 1);
+	str = (char *) array->data;
 	g_byte_array_free (array, FALSE);
 	
 	return str;
