@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -68,7 +68,15 @@ struct _GMimeObjectClass {
 };
 
 
-typedef void (*GMimePartFunc) (GMimeObject *part, gpointer data);
+/**
+ * GMimePartFunc:
+ * @part: A MIME part.
+ * @user_data: User-supplied callback data.
+ *
+ * The function signature for a callback to
+ * g_mime_message_foreach_part() and g_mime_multipart_foreach().
+ **/
+typedef void (* GMimePartFunc) (GMimeObject *part, gpointer user_data);
 
 
 GType g_mime_object_get_type (void);
