@@ -105,25 +105,30 @@ struct _GMimeParserPrivate {
 	/* header buffer */
 	char *headerbuf;
 	char *headerptr;
-	guint headerleft;
+	size_t headerleft;
 	
 	/* raw header buffer */
 	char *rawbuf;
 	char *rawptr;
-	guint rawleft;
+	size_t rawleft;
 	
-	off_t headers_start;
-	off_t header_start;
+	/* current message headerblock offsets */
+	off_t headers_begin;
+	off_t headers_end;
 	
-	int state:26;
-	unsigned int midline:1;
-	unsigned int seekable:1;
-	unsigned int scan_from:1;
-	unsigned int have_regex:1;
-	unsigned int persist_stream:1;
-	unsigned int respect_content_length:1;
+	/* current header field offset */
+	off_t header_offset;
+	
+	short int state;
+	
+	unsigned short int unused:10;
+	unsigned short int midline:1;
+	unsigned short int seekable:1;
+	unsigned short int scan_from:1;
+	unsigned short int have_regex:1;
+	unsigned short int persist_stream:1;
+	unsigned short int respect_content_length:1;
 	
-	GMimeContentType *content_type;
 	struct _header_raw *headers;
 	
 	struct _boundary_stack *bounds;
@@ -323,8 +328,10 @@ parser_init (GMimeParser *parser, GMimeStream *stream)
 	priv->rawptr = priv->rawbuf;
 	priv->rawleft = SCAN_HEAD;
 	
-	priv->headers_start = -1;
-	priv->header_start = -1;
+	priv->headers_begin = -1;
+	priv->headers_end = -1;
+	
+	priv->header_offset = -1;
 	
 	priv->midline = FALSE;
 	priv->seekable = offset != -1;
@@ -739,19 +746,31 @@ parser_step_from (GMimeParser *parser)
 	return 0;
 }
 
+static inline size_t
+nearest_pow (size_t num)
+{
+	size_t n = num > 0 ? num - 1 : 0;
+	
+	n |= n >> 1;
+	n |= n >> 2;
+	n |= n >> 4;
+	n |= n >> 8;
+	n |= n >> 16;
+	n++;
+	
+	return n;
+}
+
 #define header_append(priv, start, len) G_STMT_START {                    \
 	if (priv->headerleft <= len) {                                    \
 		size_t hlen, hoff;                                        \
 		                                                          \
-		hlen = hoff = priv->headerptr - priv->headerbuf;          \
-		hlen = hlen ? hlen : 1;                                   \
+		hoff = priv->headerptr - priv->headerbuf;                 \
+		hlen = nearest_pow (hoff + len + 1);                      \
 		                                                          \
-		while (hlen < hoff + len)                                 \
-			hlen <<= 1;                                       \
-		                                                          \
-		priv->headerbuf = g_realloc (priv->headerbuf, hlen + 1);  \
+		priv->headerbuf = g_realloc (priv->headerbuf, hlen);      \
 		priv->headerptr = priv->headerbuf + hoff;                 \
-		priv->headerleft = hlen - hoff;                           \
+		priv->headerleft = (hlen - 1) - hoff;                     \
 	}                                                                 \
 	                                                                  \
 	memcpy (priv->headerptr, start, len);                             \
@@ -763,15 +782,12 @@ parser_step_from (GMimeParser *parser)
 	if (priv->rawleft <= len) {                                       \
 		size_t hlen, hoff;                                        \
 		                                                          \
-		hlen = hoff = priv->rawptr - priv->rawbuf;                \
-		hlen = hlen ? hlen : 1;                                   \
+		hoff = priv->rawptr - priv->rawbuf;                       \
+		hlen = nearest_pow (hoff + len + 1);                      \
 		                                                          \
-		while (hlen < hoff + len)                                 \
-			hlen <<= 1;                                       \
-		                                                          \
-		priv->rawbuf = g_realloc (priv->rawbuf, hlen + 1);        \
+		priv->rawbuf = g_realloc (priv->rawbuf, hlen);            \
 		priv->rawptr = priv->rawbuf + hoff;                       \
-		priv->rawleft = hlen - hoff;                              \
+		priv->rawleft = (hlen - 1) - hoff;                        \
 	}                                                                 \
 	                                                                  \
 	memcpy (priv->rawptr, start, len);                                \
@@ -801,7 +817,7 @@ header_parse (GMimeParser *parser, struct _header_raw **tail)
 	if (*inptr != ':') {
 		/* ignore invalid headers */
 		w(g_warning ("Invalid header at %lld: '%s'",
-			     (long long) priv->header_start,
+			     (long long) priv->header_offset,
 			     priv->headerbuf));
 		
 		priv->headerleft += priv->headerptr - priv->headerbuf;
@@ -833,7 +849,7 @@ header_parse (GMimeParser *parser, struct _header_raw **tail)
 	
 	header->value = g_strndup (start, end - start);
 	
-	header->offset = priv->header_start;
+	header->offset = priv->header_offset;
 	
 	(*tail)->next = header;
 	*tail = header;
@@ -852,6 +868,7 @@ parser_step_headers (GMimeParser *parser)
 {
 	struct _GMimeParserPrivate *priv = parser->priv;
 	gboolean eoln, valid = TRUE, fieldname = TRUE;
+	gboolean continuation = FALSE;
 	struct _header_raw *hend;
 	register char *inptr;
 	char *start, *inend;
@@ -862,8 +879,10 @@ parser_step_headers (GMimeParser *parser)
 	raw_header_reset (priv);
 	header_raw_clear (&priv->headers);
 	hend = (struct _header_raw *) &priv->headers;
-	priv->headers_start = parser_offset (priv, NULL);
-	priv->header_start = parser_offset (priv, NULL);
+	priv->header_offset = parser_offset (priv, NULL);
+	
+	if (priv->headers_begin == -1)
+		priv->headers_begin = parser_offset (priv, NULL);
 	
 	inptr = priv->inptr;
 	inend = priv->inend;
@@ -883,6 +902,15 @@ parser_step_headers (GMimeParser *parser)
 		while (inptr < inend) {
 			start = inptr;
 			
+			/* if we are scanning a new line, check for a folded header */
+			if (!priv->midline && continuation && (*inptr != ' ' && *inptr != '\t')) {
+				header_parse (parser, &hend);
+				priv->header_offset = parser_offset (priv, inptr);
+				continuation = FALSE;
+				fieldname = TRUE;
+				valid = TRUE;
+			}
+			
 			eoln = inptr[0] == '\n' || (inptr[0] == '\r' && inptr[1] == '\n');
 			if (fieldname && !eoln) {
 				/* scan and validate the field name */
@@ -933,11 +961,17 @@ parser_step_headers (GMimeParser *parser)
 				inptr++;
 			
 			len = (size_t) (inptr - start);
-			raw_header_append (priv, start, len);
 			
 			if (inptr == inend) {
-				/* we don't have enough data to tell if we
-				   got all of the header or not... */
+				/* we don't have the full line, save
+				 * what we have and refill our
+				 * buffer... */
+				if (inptr > start && inptr[-1] == '\r') {
+					inptr--;
+					len--;
+				}
+				
+				raw_header_append (priv, start, len);
 				header_append (priv, start, len);
 				priv->midline = TRUE;
 				left = inend - inptr;
@@ -945,6 +979,8 @@ parser_step_headers (GMimeParser *parser)
 				goto refill;
 			}
 			
+			raw_header_append (priv, start, len);
+			
 			if (inptr > start && inptr[-1] == '\r')
 				len--;
 			
@@ -955,18 +991,10 @@ parser_step_headers (GMimeParser *parser)
 			header_append (priv, start, len);
 			
 			/* inptr has to be less than inend - 1 */
-			raw_header_append (priv, inptr, 1);
+			raw_header_append (priv, "\n", 1);
+			priv->midline = FALSE;
+			continuation = TRUE;
 			inptr++;
-			
-			if (*inptr == ' ' || *inptr == '\t') {
-				priv->midline = TRUE;
-			} else {
-				header_parse (parser, &hend);
-				priv->header_start = parser_offset (priv, inptr);
-				priv->midline = FALSE;
-				fieldname = TRUE;
-				valid = TRUE;
-			}
 		}
 		
 		left = inend - inptr;
@@ -985,6 +1013,9 @@ parser_step_headers (GMimeParser *parser)
 	if (priv->headerptr > priv->headerbuf)
 		header_parse (parser, &hend);
 	
+	if (priv->headers_end == -1)
+		priv->headers_end = parser_offset (priv, start);
+	
 	priv->state = GMIME_PARSER_STATE_HEADERS_END;
 	*priv->rawptr = '\0';
 	priv->inptr = inptr;
@@ -993,6 +1024,9 @@ parser_step_headers (GMimeParser *parser)
 	
  next_message:
 	
+	if (priv->headers_end == -1)
+		priv->headers_end = parser_offset (priv, start);
+	
 	priv->state = GMIME_PARSER_STATE_COMPLETE;
 	*priv->rawptr = '\0';
 	priv->inptr = start;
@@ -1001,6 +1035,9 @@ parser_step_headers (GMimeParser *parser)
 	
  content_start:
 	
+	if (priv->headers_end == -1)
+		priv->headers_end = parser_offset (priv, start);
+	
 	priv->state = GMIME_PARSER_STATE_CONTENT;
 	*priv->rawptr = '\0';
 	priv->inptr = start;
@@ -1064,12 +1101,16 @@ parser_step (GMimeParser *parser)
 	case GMIME_PARSER_STATE_ERROR:
 		break;
 	case GMIME_PARSER_STATE_INIT:
+		parser->priv->headers_begin = -1;
+		parser->priv->headers_end = -1;
 		if (priv->scan_from)
 			priv->state = GMIME_PARSER_STATE_FROM;
 		else
 			priv->state = GMIME_PARSER_STATE_HEADERS;
 		break;
 	case GMIME_PARSER_STATE_FROM:
+		parser->priv->headers_begin = -1;
+		parser->priv->headers_end = -1;
 		parser_step_from (parser);
 		break;
 	case GMIME_PARSER_STATE_HEADERS:
@@ -1308,7 +1349,7 @@ parser_scan_message_part (GMimeParser *parser, GMimeMessagePart *mpart, int *fou
 	
 	/* get the headers */
 	priv->state = GMIME_PARSER_STATE_HEADERS;
-	if (parser_step (parser) == -1) {
+	if (parser_step (parser) == GMIME_PARSER_STATE_ERROR) {
 		/* Note: currently cannot happen because
 		 * parser_step_headers() never returns error */
 		*found = FOUND_EOS;
@@ -1364,7 +1405,7 @@ parser_construct_leaf_part (GMimeParser *parser, GMimeContentType *content_type,
 	
 	if (priv->state == GMIME_PARSER_STATE_HEADERS_END) {
 		/* skip empty line after headers */
-		if (parser_step (parser) == -1) {
+		if (parser_step (parser) == GMIME_PARSER_STATE_ERROR) {
 			*found = FOUND_EOS;
 			return object;
 		}
@@ -1461,7 +1502,7 @@ parser_scan_multipart_subparts (GMimeParser *parser, GMimeMultipart *multipart)
 		
 		/* get the headers */
 		priv->state = GMIME_PARSER_STATE_HEADERS;
-		if (parser_step (parser) == -1) {
+		if (parser_step (parser) == GMIME_PARSER_STATE_ERROR) {
 			found = FOUND_EOS;
 			break;
 		}
@@ -1518,7 +1559,7 @@ parser_construct_multipart (GMimeParser *parser, GMimeContentType *content_type,
 	
 	if (priv->state == GMIME_PARSER_STATE_HEADERS_END) {
 		/* skip empty line after headers */
-		if (parser_step (parser) == -1) {
+		if (parser_step (parser) == GMIME_PARSER_STATE_ERROR) {
 			*found = FOUND_EOS;
 			return object;
 		}
@@ -1560,7 +1601,7 @@ parser_construct_part (GMimeParser *parser)
 	
 	/* get the headers */
 	while (priv->state < GMIME_PARSER_STATE_HEADERS_END) {
-		if (parser_step (parser) == -1)
+		if (parser_step (parser) == GMIME_PARSER_STATE_ERROR)
 			return NULL;
 	}
 	
@@ -1607,13 +1648,13 @@ parser_construct_message (GMimeParser *parser)
 	
 	/* scan the from-line if we are parsing an mbox */
 	while (priv->state != GMIME_PARSER_STATE_HEADERS) {
-		if (parser_step (parser) == -1)
+		if (parser_step (parser) == GMIME_PARSER_STATE_ERROR)
 			return NULL;
 	}
 	
 	/* parse the headers */
 	while (priv->state < GMIME_PARSER_STATE_HEADERS_END) {
-		if (parser_step (parser) == -1)
+		if (parser_step (parser) == GMIME_PARSER_STATE_ERROR)
 			return NULL;
 	}
 	
@@ -1723,3 +1764,45 @@ g_mime_parser_get_from_offset (GMimeParser *parser)
 	
 	return priv->from_offset;
 }
+
+
+/**
+ * g_mime_parser_get_headers_begin:
+ * @parser: a #GMimeParser context
+ *
+ * Gets the stream offset of the beginning of the headers of the most
+ * recently parsed message.
+ *
+ * Returns: the offset of the beginning of the headers of the most
+ * recently parsed message or %-1 on error.
+ *
+ * Since: 2.2.23
+ **/
+off_t
+g_mime_parser_get_headers_begin (GMimeParser *parser)
+{
+	g_return_val_if_fail (GMIME_IS_PARSER (parser), -1);
+	
+	return parser->priv->headers_begin;
+}
+
+
+/**
+ * g_mime_parser_get_headers_end:
+ * @parser: a #GMimeParser context
+ *
+ * Gets the stream offset of the end of the headers of the most
+ * recently parsed message.
+ *
+ * Returns: the offset of the end of the headers of the most recently
+ * parsed message or %-1 on error.
+ *
+ * Since: 2.2.23
+ **/
+off_t
+g_mime_parser_get_headers_end (GMimeParser *parser)
+{
+	g_return_val_if_fail (GMIME_IS_PARSER (parser), -1);
+	
+	return parser->priv->headers_end;
+}
