@@ -1,20 +1,21 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public License
+ *  as published by the Free Software Foundation; either version 2.1
+ *  of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free
+ *  Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
+ *  02110-1301, USA.
  */
 
 
@@ -53,9 +54,21 @@ struct _GMimeParserClass {
 	
 };
 
-typedef void (*GMimeParserHeaderRegexFunc) (GMimeParser *parser, const char *header,
-					    const char *value, off_t offset,
-					    gpointer user_data);
+
+/**
+ * GMimeParserHeaderRegexFunc:
+ * @parser: The #GMimeParser object.
+ * @header: The header field matched.
+ * @value: The header field value.
+ * @offset: The header field offset.
+ * @user_data: The user-supplied callback data.
+ *
+ * Function signature for the callback to
+ * g_mime_parser_set_header_regex().
+ **/
+typedef void (* GMimeParserHeaderRegexFunc) (GMimeParser *parser, const char *header,
+					     const char *value, off_t offset,
+					     gpointer user_data);
 
 
 GType g_mime_parser_get_type (void);
@@ -90,7 +103,9 @@ char *g_mime_parser_get_from (GMimeParser *parser);
 
 off_t g_mime_parser_get_from_offset (GMimeParser *parser);
 
+off_t g_mime_parser_get_headers_begin (GMimeParser *parser);
+off_t g_mime_parser_get_headers_end (GMimeParser *parser);
+
 G_END_DECLS
 
 #endif /* __GMIME_PARSER_H__ */
-
