@@ -173,9 +173,9 @@ stream_read (GMimeStream *stream, char *buf, size_t len)
 				buffer->bufptr = buffer->buffer;
 			}
 			
-			if (n == -1) {
+			if (n <= 0) {
 				if (nread == 0)
-					return -1;
+					return n;
 				
 				break;
 			}
@@ -204,9 +204,9 @@ stream_read (GMimeStream *stream, char *buf, size_t len)
 				
 				buffer->bufend = n > 0 ? buffer->bufptr + n : buffer->bufptr;
 				
-				if (n == -1) {
+				if (n <= 0) {
 					if (nread == 0)
-						return -1;
+						return n;
 					
 					break;
 				}
@@ -482,6 +482,9 @@ stream_seek_cache_read (GMimeStream *stream, off_t offset, GMimeSeekWhence whenc
 			if (real > stream->bound_end || real < stream->bound_start)
 				return -1;
 		}
+		break;
+	default:
+		return -1;
 	}
 	
 	if (real > stream->position) {
@@ -682,10 +685,8 @@ g_mime_stream_buffer_gets (GMimeStream *stream, char *buf, size_t max)
 					/* buffer more data */
 					buffer->bufptr = buffer->buffer;
 					n = g_mime_stream_read (buffer->source, buffer->buffer, BLOCK_BUFFER_LEN);
-					if (n <= 0) {
-						buffer->buflen = 0;
+					if (n <= 0)
 						break;
-					}
 					
 					buffer->buflen = n;
 				}
@@ -739,10 +740,6 @@ g_mime_stream_buffer_gets (GMimeStream *stream, char *buf, size_t max)
 			*outptr++ = c;
 	}
 	
-	/* strip \r */
-	if (c == '\n' && outptr > buf && outptr[-1] == '\r')
-		outptr--;
-	
 	if (outptr <= outend) {
 		/* this should always be true unless @max == 0 */
 		*outptr = '\0';
