@@ -1,20 +1,21 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public License
+ *  as published by the Free Software Foundation; either version 2.1
+ *  of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free
+ *  Software Foundation, 51 Franklin Street, Fifth Floor, Boston, MA
+ *  02110-1301, USA.
  */
 
 
@@ -24,6 +25,21 @@
 
 #include "gmime-stream-file.h"
 
+
+/**
+ * SECTION: gmime-stream-file
+ * @title: GMimeStreamFile
+ * @short_description: A Standard-C FILE-based stream
+ * @see_also: #GMimeStream
+ *
+ * A simple #GMimeStream implementation that sits on top of the
+ * Standard C FILE pointer based I/O layer. Unlike #GMimeStreamFs, a
+ * #GMimeStreamFile will typically buffer read and write operations at
+ * the FILE level and so it may be wasteful to wrap one in a
+ * #GMimeStreamBuffer stream.
+ **/
+
+
 static void g_mime_stream_file_class_init (GMimeStreamFileClass *klass);
 static void g_mime_stream_file_init (GMimeStreamFile *stream, GMimeStreamFileClass *klass);
 static void g_mime_stream_file_finalize (GObject *object);
@@ -113,7 +129,7 @@ static ssize_t
 stream_read (GMimeStream *stream, char *buf, size_t len)
 {
 	GMimeStreamFile *fstream = (GMimeStreamFile *) stream;
-	ssize_t nread;
+	size_t nread;
 	
 	if (stream->bound_end != -1 && stream->position >= stream->bound_end)
 		return -1;
@@ -127,14 +143,14 @@ stream_read (GMimeStream *stream, char *buf, size_t len)
 	if ((nread = fread (buf, 1, len, fstream->fp)) > 0)
 		stream->position += nread;
 	
-	return nread;
+	return (ssize_t) nread;
 }
 
 static ssize_t
 stream_write (GMimeStream *stream, const char *buf, size_t len)
 {
 	GMimeStreamFile *fstream = (GMimeStreamFile *) stream;
-	ssize_t nwritten;
+	size_t nwritten;
 	
 	if (stream->bound_end != -1 && stream->position >= stream->bound_end)
 		return -1;
@@ -148,7 +164,7 @@ stream_write (GMimeStream *stream, const char *buf, size_t len)
 	if ((nwritten = fwrite (buf, 1, len, fstream->fp)) > 0)
 		stream->position += nwritten;
 	
-	return nwritten;
+	return (ssize_t) nwritten;
 }
 
 static int
