@@ -95,8 +95,9 @@ header_cb (GMimeParser *parser, const char *header, const char *value, off_t off
 static void
 test_parser (GMimeParser *parser, GMimeStream *mbox, GMimeStream *summary)
 {
+	off_t headers_begin, headers_end, start, end;
 	GMimeMessage *message;
-	off_t start, end;
+	const char *exev;
 	int nmsg = 0;
 	char *from;
 	
@@ -107,10 +108,17 @@ test_parser (GMimeParser *parser, GMimeStream *mbox, GMimeStream *summary)
 		
 		end = g_mime_parser_tell (parser);
 		
+		headers_begin = g_mime_parser_get_headers_begin (parser);
+		headers_end = g_mime_parser_get_headers_end (parser);
+		
 		g_mime_stream_printf (summary, "message offsets: " OFF_T ", " OFF_T "\n", start, end);
+		g_mime_stream_printf (summary, "header offsets: " OFF_T ", " OFF_T "\n",
+				      headers_begin, headers_end);
 		
 		from = g_mime_parser_get_from (parser);
 		g_mime_stream_printf (summary, "%s\n", from);
+		exev = g_mime_message_get_header (message, "X-Evolution");
+		g_mime_stream_printf (summary, "X-Evolution: %s\n", exev ? exev : "None");
 		print_mime_struct (summary, message->mime_part, 0);
 		g_mime_stream_write (summary, "\n", 1);
 		
